@@ -13,7 +13,7 @@ use std::{
   env,
   fmt::Debug,
   ops::Deref,
-  path::{Path, PathBuf},
+  path::PathBuf,
   process::{exit, Command},
   str::FromStr,
 };
@@ -106,7 +106,7 @@ fn main() {
   env_logger::init();
 
   exit(rustc_driver::catch_with_exit_code(move || {
-    let mut orig_args: Vec<String> = env::args().collect();
+    let orig_args: Vec<String> = env::args().collect();
 
     let sys_root_arg = arg_value(&orig_args, "--sysroot", |_| true);
     let have_sys_root_arg = sys_root_arg.is_some();
@@ -146,39 +146,28 @@ fn main() {
         "need to specify SYSROOT env var during flowistry compilation, or use rustup or multirust",
       );
 
-    if let Some(pos) = orig_args.iter().position(|arg| arg == "--rustc") {
-      orig_args.remove(pos);
-      orig_args[0] = "rustc".to_string();
+    let mut args: Vec<String> = orig_args.clone();
 
-      // if we call "rustc", we need to pass --sysroot here as well
-      let mut args: Vec<String> = orig_args.clone();
-      if !have_sys_root_arg {
-        args.extend(vec!["--sysroot".into(), sys_root]);
-      };
-
-      return rustc_driver::RunCompiler::new(&args, &mut DefaultCallbacks).run();
-    }
-
-    // Setting RUSTC_WRAPPER causes Cargo to pass 'rustc' as the first argument.
-    // We're invoking the compiler programmatically, so we ignore this/
-    let wrapper_mode =
-      orig_args.get(1).map(Path::new).and_then(Path::file_stem) == Some("rustc".as_ref());
-
-    if wrapper_mode {
-      // we still want to be able to invoke it normally though
-      orig_args.remove(1);
-    }
+    // remove flowistry-driver from invocation
+    args.remove(0);
 
     // this conditional check for the --sysroot flag is there so users can call
-    // `flowistry-driver` directly
-    // without having to pass --sysroot or anything
-    let mut args: Vec<String> = orig_args.clone();
+    // `flowistry-driver` directly without having to pass --sysroot or anything
     if !have_sys_root_arg {
       args.extend(vec!["--sysroot".into(), sys_root]);
     }
 
-    let in_primary_package = env::var("CARGO_PRIMARY_PACKAGE").is_ok();
-    if in_primary_package {
+    let mut is_flowistry = false;
+    args.retain(|arg| {
+      if arg.starts_with("--flowistry") {
+        is_flowistry = true;
+        false
+      } else {
+        true
+      }
+    });
+
+    if is_flowistry {
       run_flowistry(&args).unwrap();
       Ok(())
     } else {
